@@ -1,6 +1,6 @@
-Sel_type_data <-
+StartMMD <-
 function(){
-tt <- tktoplevel() # on crée une fenetre
+tt <- tktoplevel() # on cr\'ee une fenetre
 tkwm.geometry(tt, "375x450")
 tkwm.minsize(tt, 375, 450)
 tktitle(tt) <- "[AnthropMMD] About your dataset..." # Le titre qui s'affichera dans la barre de fenetre
@@ -14,7 +14,7 @@ frameDelimiters <- tkframe(tt, relief="groove", borderwidth=0) # declaration d'u
 # Frame sur le type des donnees :
 rb1 <- tkradiobutton(frameTypeData) # declaration d'un premier bouton radio
 rb2 <- tkradiobutton(frameTypeData) # declaration d'un second bouton radio
-rbValue <- tclVar("raw_data") # cette variable (initialisée à Raw) contiendra au final le choix retenu par l'utilisateur via son bouton
+rbValue <- tclVar("raw_data") # cette variable (initialis\'ee \`a Raw) contiendra au final le choix retenu par l'utilisateur via son bouton
 tkconfigure(rb1,variable=rbValue,value="raw_data",text="Raw (binary) dataset...") # affectation d'une variable tcltk a chaque bouton radio
 tkconfigure(rb2,variable=rbValue,value="summarized_data",text="Summarized (groups n's and frequencies) data...")
 
@@ -37,99 +37,103 @@ sepDecWidget <- tkentry(frameTypeData, width = 1, bg="white", textvariable = sep
 # Mise en forme :
 tkgrid(frameTypeData)
 tkgrid(tklabel(frameTypeData,text="Type of your dataset", font=fontHeading))
-tkgrid(tklabel(frameTypeData,text="    ")) # ligne vide pour aérer
+tkgrid(tklabel(frameTypeData,text="    ")) # ligne vide pour a\'erer
 tkgrid(rb1, sticky="w")
 tkgrid(tklabel(frameTypeData,text="... with column names"),cb1,sticky="e")
 tkgrid(tklabel(frameTypeData,text="... with row names"),cb2,sticky="e")
 tkgrid(tklabel(frameTypeData,text="The first column must be a group identifier."))
-tkgrid(tklabel(frameTypeData,text="    ")) # ligne vide pour aérer
+tkgrid(tklabel(frameTypeData,text="    ")) # ligne vide pour a\'erer
 tkgrid(rb2, sticky="w")
 tkgrid(tklabel(frameTypeData,text="... with this character used for decimal points :"),sepDecWidget,sticky="e")
 tkgrid(tklabel(frameTypeData,text="Row and column names are mandatory here."))
 
-tkgrid(tklabel(tt,text="    ")) # ligne vide pour aérer
+tkgrid(tklabel(tt,text="    ")) # ligne vide pour a\'erer
 tkgrid(tklabel(tt,text="Information", font=fontHeading))
 tkgrid(tklabel(tt,text="Please note that only .csv and .txt files \n are accepted by the program."))
-tkgrid(tklabel(tt,text="    ")) # ligne vide pour aérer
+tkgrid(tklabel(tt,text="    ")) # ligne vide pour a\'erer
 
 tkgrid(frameDelimiters)
 tkgrid(tklabel(frameDelimiters,text="Character used as field separator :"),sepChampWidget,sticky="e")
 tkgrid(tklabel(frameDelimiters,text="String used for missing values :"),textNaWidget, sticky="e")
 
-tkgrid(tklabel(tt,text="    ")) # ligne vide pour aérer
-OK.but <- tkbutton(tt,text="OK",command=function() tkdestroy(tt), relief="groove",borderwidth=3,width=7,bg="green4",fg="white")
-tkgrid(OK.but)
-tkfocus(tt)
-tkwait.window(OK.but) # TRES IMPORTANT : l'exécution s'arrête ici tant que l'utilisateur n'a pas cliqué sur OK 
-
+tkgrid(tklabel(tt,text="    ")) # ligne vide pour a\'erer
+#### MODIFIE lgrement  partir d'ici
+OnOK<-function()
+{
 user_choice = list(as.character(tclvalue(rbValue)), tclvalue(val_header), tclvalue(val_rownames), tclvalue(sepChampVarTcl), tclvalue(sepDecVarTcl), tclvalue(textNaVarTcl))
 names(user_choice) = c("Type_data", "Colnames", "Rownames", "FieldSep", "DecPoint", "TextNA")
-return(user_choice)
+tkdestroy(tt)
+Gabarit_MMD(user_choice)
+}
+OK.but <- tkbutton(tt,text="OK",command=OnOK , relief="groove",borderwidth=3,width=7,bg="green4",fg="white")
+tkgrid(OK.but)
+tkfocus(tt)
+#tkwait.window(OK.but) # TRES IMPORTANT : l'ex\'ecution s'arr\^ete ici tant que l'utilisateur n'a pas cliqu\'e sur OK 
+tkwait.window(tt)  # MODIFIE lgrement
 }
 
 
-StartMMD <-
-function(){
+Gabarit_MMD <-
+function(type_data){   #MODIFIE : la fonction a un paramtre, envoy par Sel_type_data
 
-myenvg = new.env() # environnement privé au package ; contiendra les variables globales
+myenvg = new.env() # environnement priv\'e au package ; contiendra les variables globales
 GoOn <- 1 # variable globale indiquant si le programme doit continuer ou se terminer
 
-## FENÊTRE DE CHOIX DU TYPE DES DONNÉES :
-# Deux possibilités : l'utilisateur a-t-il un tableau de données binaires (brutes) ou un tableau d'effectifs et de proportions (données résumées) ?
-type_data = Sel_type_data() # on récupère ici le choix de l'utilisateur
+## FENETRE DE CHOIX DU TYPE DES DONN\'EES :
+# Deux possibilit\'es : l'utilisateur a-t-il un tableau de donn\'ees binaires (brutes) ou un tableau d'effectifs et de proportions (donn\'ees r\'esum\'ees) ?
+#type_data = Sel_type_data() # on r\'ecup\`ere ici le choix de l'utilisateur SUPPRIME
 
-
-## FENÊTRE DE CHARGEMENT DES DONNÉES :
-# Faire charger les données
-fileName <- tclvalue(tkgetOpenFile(filetypes="{{CSV files} {.csv}} {{Text files} {.txt}}"))
+## FENETRE DE CHARGEMENT DES DONN\'EES :
+# Faire charger les donn\'ees
+fileName <- tclvalue(tkgetOpenFile(filetypes="{{Text files} {.txt}} {{CSV files} {.csv}}"))
 if (!nchar(fileName)) {
  tkmessageBox(message = "No file was selected!")
  GoOn <- 0  
 }
 
 
-## CHARGEMENT EFFECTIF DES DONNÉES :
-if ((GoOn == 1) & (type_data$Type_data=="raw_data")) { # si le programme peut continuer normalement et que l'utilisateur a chargé des données brutes
- bdd = read.table(file=fileName, header=(type_data$Colnames=="1"), sep=type_data$FieldSep, dec=type_data$DecPoint, na.strings=type_data$TextNA) # dans un premier temps on ne met pas row.names=1, pour vérifier que les noms d'individus ne comportent pas de doublons
+## CHARGEMENT EFFECTIF DES DONN\'EES :
+if ((GoOn == 1) & (type_data$Type_data=="raw_data")) { # si le programme peut continuer normalement et que l'utilisateur a charg\'e des donn\'ees brutes
+ bdd = read.table(file=fileName, header=(type_data$Colnames=="1"), sep=type_data$FieldSep, dec=type_data$DecPoint, na.strings=type_data$TextNA) # dans un premier temps on ne met pas row.names=1, pour v\'erifier que les noms d'individus ne comportent pas de doublons
  if (anyDuplicated(bdd[,1])>0 & (type_data$Rownames=="1")) {
-  tkmessageBox(title="[AnthropMMD] Duplicated row names", message = "Warning : there are duplicates in the names of your individuals. The program will continue normally anyway, but please check your data.", icon = "warning", type = "ok") # on prévient l'utilisateur si son fichier a des doublons
+  tkmessageBox(title="[AnthropMMD] Duplicated row names", message = "Warning : there are duplicates in the names of your individuals. The program will continue normally anyway, but please check your data.", icon = "warning", type = "ok") # on pr\'evient l'utilisateur si son fichier a des doublons
  }
- if (type_data$Colnames=="1") {bdd = bdd[,-1]} # on retire la première colonne (i.e. les noms d'individus) le cas echeant
+ if (type_data$Colnames=="1") {bdd = bdd[,-1]} # on retire la premi\`ere colonne (i.e. les noms d'individus) le cas echeant
 
-} else if ((GoOn == 1) & (type_data$Type_data=="summarized_data")) { # si le programme peut continuer normalement et que l'utilisateur a chargé un résumé
+} else if ((GoOn == 1) & (type_data$Type_data=="summarized_data")) { # si le programme peut continuer normalement et que l'utilisateur a charg\'e un r\'esum\'e
  bdd = read.csv(file=fileName, header=TRUE, row.names=1, dec=",", sep=";")
 }
 
 ## CONTROLE DU TYPE DES DONNEES :
-if ((GoOn == 1) & (type_data$Type_data=="raw_data")) { # si le programme peut continuer normalement et que l'utilisateur a chargé des données brutes
+if ((GoOn == 1) & (type_data$Type_data=="raw_data")) { # si le programme peut continuer normalement et que l'utilisateur a charg\'e des donn\'ees brutes
  for (j in 2:ncol(bdd)) {
   if (nlevels(factor(bdd[,j]))>2) {
-   tkmessageBox(title="[AnthropMMD] Invalid dataset", message = "Error : invalid dataset (at least one variable is not dichotomous).", icon = "error", type = "ok") # on prévient l'utilisateur si son fichier a des doublons
+   tkmessageBox(title="[AnthropMMD] Invalid dataset", message = "Error : invalid dataset (at least one variable is not dichotomous).", icon = "error", type = "ok") # on pr\'evient l'utilisateur si son fichier a des doublons
    GoOn <- 0
    break
   }
  }
 }
 
-## FENÊTRE DE PARAMÉTRAGE DE L'ANALYSE :
+## FENETRE DE PARAM\'ETRAGE DE L'ANALYSE :
 if (GoOn == 1) {
  UserSettings <- AnaSettings(bdd, type.data=type_data$Type_data)
 }
 
 if (GoOn == 1) {
-if (length(UserSettings$Groupes_retenus)<2) { # si l'utilisateur a retenu moins de 2 groupes, le programme s'arrête
+if (length(UserSettings$Groupes_retenus)<2) { # si l'utilisateur a retenu moins de 2 groupes, le programme s'arr\^ete
  tkmessageBox(title="[AnthropMMD] Error", message = "You must select at least two groups.", icon = "error", type = "ok")
  GoOn <- 0 
 } else if (type_data$Type_data=="raw_data") { # cas d'une base brute 0/1
  groups_to_keep = levels(factor(bdd[,1]))[UserSettings$Groupes_retenus]
- bdd = bdd[bdd[,1] %in% groups_to_keep, ] # la bdd est restreinte aux groupes sélectionnés par l'utilisateur
+ bdd = bdd[bdd[,1] %in% groups_to_keep, ] # la bdd est restreinte aux groupes s\'electionn\'es par l'utilisateur
  bdd[,1] = factor(bdd[,1])
-} else if (type_data$Type_data=="summarized_data") { # cas d'une base résumée
+} else if (type_data$Type_data=="summarized_data") { # cas d'une base r\'esum\'ee
  bdd = bdd[c(UserSettings$Groupes_retenus, UserSettings$Groupes_retenus+nrow(bdd)/2) ,]
 }
 }
 
-## ON LANCE DONC DÉSORMAIS LE CALCUL DU MMD :
+## ON LANCE DONC D\'ESORMAIS LE CALCUL DU MMD :
 if (GoOn == 1) {
  prep = Prepa_MMD(bdd, type=type_data$Type_data, k=UserSettings$Nb_min_indiv, all_vars=UserSettings$All_vars, idiosync=UserSettings$All_BO_vars)
 }
@@ -140,7 +144,7 @@ if ((!is.vector(prep)) & (GoOn==1)) {
  resul = Mat_MMD(Mat_eff=prep[1:(nrow(prep)/2), ], Mat_prop=prep[(nrow(prep)/2 + 1):nrow(prep), ], formule=UserSettings$Formula, corrFT=UserSettings$FTcor)
 } else {
  GoOn <- 0
- tkmessageBox(title="[AnthropMMD] Invalid selection", message = "Error : no variable meets your selection criteria in the dataset. The program will stop : please try again with more flexible criteria.", icon = "error", type = "ok") # on prévient l'utilisateur si ses criteres de selection sont trop severes
+ tkmessageBox(title="[AnthropMMD] Invalid selection", message = "Error : no variable meets your selection criteria in the dataset. The program will stop : please try again with more flexible criteria.", icon = "error", type = "ok") # on pr\'evient l'utilisateur si ses criteres de selection sont trop severes
 }
 
 # if (GoOn == 1) {
@@ -179,6 +183,8 @@ if (ncol(resul$MMDMatrix)>2) {
 
 # ET ON PROPOSE A L'UTILISATEUR DE SAUVEGARDER SA MATRICE DE MMD :
 if (GoOn == 1) {
+ cat("\n", "MMD Matrix:", "\n")
+ print(resul$MMDMatrix)
  cat("\n", "Significant MMD are indicated by stars:", "\n")
  print(signif)
  if(UserSettings$IDP) {
